@@ -7,10 +7,11 @@ from .utils import BaseObject, BoolIntType
 class Signer(BaseObject):
     validate_on_change = False
 
-    def __init__(self, id=None, name=None, email=None, **kwargs):
+    def __init__(self, id=None, name=None, email=None, language=None, **kwargs):
         kwargs['id'] = id
         kwargs['name'] = name
         kwargs['email'] = email
+        kwargs['language'] = language
 
         kwargs = self.clear_kwargs(kwargs)
 
@@ -36,6 +37,7 @@ class SignerModel(Model):
     status = StringType()
     embedded_signing_url = StringType()
     deliver_email = BoolIntType()
+    language = StringType()
 
     class Options:
         serialize_when_none = False
